# Inject the right home-manager config for the machine.

{ config, pkgs, lib, ... }:

# TODO can we automate the installation of home-manager ?
# sudo nix-channel --add https://github.com/nix-community/home-manager/archive/release-23.05.tar.gz home-manager
{
  imports = [
   <home-manager/nixos>
  ];

  # Let Home Manager install and manage itself.
  #programs.home-manager.enable = true;

  home-manager.users.mrflos = { pkgs, ... }: {
    home.stateVersion = "23.05";    

    accounts.email.accounts = {
      "mrflos@chmok.net" = {
        realName = "Florian Schmitt";
        userName = "mrflos@chmok.net";
        address = "mrflos@chmok.net";

        primary = true;
        thunderbird = {
          enable = true;
        };
        imap = {
          host = "mail.gandi.net";
          port = 143;
          tls.useStartTls = true;
        };

        smtp = {
          host = "mail.gandi.net";
          port = 587;
          tls.useStartTls = true;
        };
      };
      "contact@yeswiki.pro" = {
        realName = "YesWiki.pro";
        userName = "contact@yeswiki.pro";
        address = "contact@yeswiki.pro";

        primary = false;
        thunderbird = {
          enable = true;
        };
        imap = {
          host = "mail.gandi.net";
          port = 143;
          tls.useStartTls = true;
        };

        smtp = {
          host = "mail.gandi.net";
          port = 587;
          tls.useStartTls = true;
        };
      };
    };

    programs.git = {
      enable = true;
      userName = "Florian Schmitt";
      userEmail = "mrflos@gmail.com";
      extraConfig = {
        pull.rebase = true;
        init.defaultBranch = "main";
      };
    };
    
    programs.thunderbird = {
      enable = true;
      profiles.default = {
        isDefault = true;
      };
    };


    # gtk = {
    #   enable = true;

    #   iconTheme = {
    #     name = "Papirus-Dark";
    #     package = pkgs.papirus-icon-theme;
    #   };

    #   theme = {
    #     name = "dracula";
    #     package = pkgs.dracula-theme;
    #   };

    #   cursorTheme = {
    #     name = "Numix-Cursor";
    #     package = pkgs.numix-cursor-theme;
    #   };

    #   gtk3.extraConfig = {
    #     Settings = ''
    #       gtk-application-prefer-dark-theme=1
    #     '';
    #   };

    #   gtk4.extraConfig = {
    #     Settings = ''
    #       gtk-application-prefer-dark-theme=1
    #     '';
    #   };
    # };

    #  dconf.settings = {
    #   "org/gnome/shell" = {
    #     disable-user-extensions = false;
    #     favorite-apps = [
    #       "firefox.desktop"
    #       "thunderbird.desktop"
    #       "org.gnome.Nautilus.desktop"
    #       "kitty.desktop"
    #       "element.desktop"
    #       "mattermost.desktop"
    #       "codium.desktop"
    #       "virt-manager.desktop"
    #     ];
    #   };
    #   "org/gnome/desktop/interface" = {
    #     color-scheme = "prefer-dark";
    #     enable-hot-corners = false;
    #   };
    #   "org/gnome/desktop/wm/preferences" = {
    #     workspace-names = [ "Principal" ];
    #   };
      # "org/gnome/desktop/background" = {
      #   picture-uri = "file:///run/current-system/sw/share/backgrounds/gnome/vnc-l.png";
      #   picture-uri-dark = "file:///run/current-system/sw/share/backgrounds/gnome/vnc-d.png";
      # };
      # "org/gnome/desktop/screensaver" = {
      #   picture-uri = "file:///run/current-system/sw/share/backgrounds/gnome/vnc-d.png";
      #   primary-color = "#3465a4";
      #   secondary-color = "#000000";
      # };
    # };
    # home.packages = with pkgs; [
    #   gnomeExtensions.user-themes
    #   gnomeExtensions.tray-icons-reloaded
    #   gnomeExtensions.vitals
    #   gnomeExtensions.dash-to-panel
    #   gnomeExtensions.sound-output-device-chooser
    #   gnomeExtensions.space-bar
    # ];
    # home.sessionVariables.GTK_THEME = "dracula";

  };

  users.users.mrflos = {
    isNormalUser = true;
    description = "mrflos";
    createHome = true;
    extraGroups = [ "docker" "libvirtd" "lxd" "networkmanager" "wheel" ];
    uid = 1000;
    shell = pkgs.zsh;
  };

  nix.settings.trusted-users = [ "mrflos" ];

  home-manager.useGlobalPkgs = true;
}
